@@ -135,6 +135,9 @@ class ExtForm(BaseExtPanel):
                     value.hour, value.minute, value.second
                 ) if not is_secret_token(value) else six.text_type(value)
 
+            elif isinstance(item, fields.ExtMultipleDateField):
+                item.value = value
+
             elif isinstance(item, simple.ExtDateTimeField):
                 if isinstance(value, datetime.datetime):
                     item.value = '%02d.%02d.%04d %02d:%02d:%02d' % (
@@ -194,15 +197,7 @@ class ExtForm(BaseExtPanel):
                         'Pack %s must provide ISelectablePack interface' %
                         bind_pack
                     )
-                    if hasattr(bind_pack, 'get_display_record'):
-                        attrs = set(item.fields)
-                        attrs.add(item.value_field)
-                        attrs.add(item.display_field)
-                        record = bind_pack.get_display_record(value,
-                                                              list(attrs))
-                        if record:
-                            item.set_value_from_model(record)
-                    elif hasattr(bind_pack, 'get_record'):
+                    if hasattr(bind_pack, 'get_record'):
                         record = bind_pack.get_record(value)
                         if record:
                             item.set_value_from_model(record)
@@ -283,10 +278,7 @@ class ExtForm(BaseExtPanel):
                         return obj[names[0]], True
                     else:
                         value = getattr(obj, names[0])
-                        if callable(value) and not hasattr(value, 'model'):
-                            return value(), True
-                        else:
-                            return value, True
+                        return value() if callable(value) else value, True
                 else:
                     nested = (
                         getattr(obj, names[0])
@@ -336,12 +328,15 @@ class ExtForm(BaseExtPanel):
             """
             if hasattr(obj, name):
                 l_field = getattr(obj, name)
-                if (
-                    l_field and
-                    os.path.exists(l_field.path) and
+                if l_field and (
+                    # Загружается новый файл
                     (
-                        os.path.basename(l_field.file.name)
-                    ).lower() != (field.value).lower()
+                        os.path.exists(l_field.path)
+                        and os.path.basename(l_field.file.name).lower() !=
+                        field.value.lower()
+                    )
+                    # Файл удаляется
+                    or not field.value
                 ):
                     # Сначало нужно удалить thumbnail картинки
                     if isinstance(field, fields.ExtImageUploadField) and (
@@ -366,6 +361,7 @@ class ExtForm(BaseExtPanel):
                     l_field.delete(save=False)
 
                 if field.memory_file:
+                    # Прислали новый файл
                     cont_file = ContentFile(field.memory_file.read())
                     name_file = field.memory_file.name
 
@@ -527,6 +523,15 @@ class ExtForm(BaseExtPanel):
                     val = d.time()
                 else:
                     val = None
+
+            elif isinstance(item, fields.ExtMultipleDateField):
+                if val:
+                    val = tuple(
+                        datetime.datetime.strptime(d.strip(), '%d.%m.%Y')
+                        for d in val.split(item.delimiter)
+                    )
+                else:
+                    val = ()
             elif isinstance(item, simple.ExtDateTimeField):
                 if val and val.strip():
                     val = datetime.datetime.strptime(val, '%d.%m.%Y %H:%M:%S')
@@ -705,7 +710,7 @@ class ExtPanel(BaseExtPanel):
         return self._items
 
 
-#==============================================================================
+# =============================================================================
 class ExtTitlePanel(ExtPanel):
     """
     Расширенная панель с возможностью добавления контролов в заголовок.
