@@ -1,4 +1,4 @@
-{# new Ext.tree.AsyncTreeNode -- нельзя использовать, так как работает некорректно с вложеной иерархией #} 
+{# new Ext.tree.AsyncTreeNode -- нельзя использовать, так как работает некорректно с вложеной иерархией #}
 {
 	expanded: {{ component.expanded|lower }}
 	,id: '{{ component.client_id }}'
@@ -6,21 +6,19 @@
 		,checked: {{ component.checked|lower }}
 	{% endif %}
 	{% for k, v in component.items.items %}
-		,{{ k }}:'{{ v }}'	
+		,{{ k }}:'{{ v }}'
 	{%endfor%}
-	
-	{% if component.auto_check %}
-		{% if component.has_children %}
-		,'leaf': false
-		{% else %}
-		,'leaf': true
-		{% endif %}
-	{% endif %}
-	
+
 	{% if component.has_children %}
-	,'children': {{ component.t_render_children|safe }}	
+	,'leaf': false
+	{% else %}
+	,'leaf': true
 	{% endif %}
-    
+
+	{% if component.has_children %}
+	,'children': {{ component.t_render_children|safe }}
+	{% endif %}
+
     {% if component.icon_cls %}
 	,'iconCls': '{{ component.icon_cls|safe }}'
 	{% endif %}
